@@ -5,7 +5,8 @@ globalVariables(c(".", "Value",                                  ## Global varia
                   "mean_r", "sd_res", "rtpa", "rxpa", "rtya",    ## Global variables defined for the .ma_r_ic function
                   "rxy",                                         ## Global variables defined for the .ma_r_bb function
                   "d", "n_1", "n_2", "n_1_split", "n_2_split",   ## Global variables defined for the .ma_d_bb function
-                  "difference", "construct_x", "construct_y"))
+                  "difference", "construct_x", "construct_y",
+                  "group", "y_name"))
 
 
 
